translate.convert.po2oo.oocheckfilter

Package translate :: Package convert :: Module po2oo :: Class oocheckfilter |
[hide private]
[frames] | no frames]

# Class oocheckfilter

source code

Instance Methods | [hide private]
validelement(self, unit, filename, filteraction) Returns whether or not to use unit in conversion. | source code
Inherited from `filters.pofilter.pocheckfilter`: `__init__`, `filterfile`, `filterunit`, `getfilterdocs`

Method Details | [hide private]

### validelement(self, unit, filename, filteraction) | source code
Returns whether or not to use unit in conversion. (filename is just for error reporting)